@@ -352,6 +352,7 @@ private:
 
 	volatile int timing;
 
+	const char *volatile domain;
 	const char *volatile localnames;
 	const char *volatile restricted;
 	const char *volatile trusted;
@@ -454,6 +455,7 @@ public:
 	static bool classify(rtpproxy::session *session, rtpproxy::session *source, struct sockaddr *addr);
 	static void activate(MappedRegistry *rr);
 	static void expire(MappedRegistry *rr);
+	static void logging(MappedRegistry *rr, const char *reason);
 	static void registration(int id, modules::regmode_t mode);
 	static bool authenticate(int id, const char *realm);
 	static MappedRegistry *redirect(const char *target);
@@ -522,7 +524,7 @@ private:
 	char display[MAX_DISPLAY_SIZE];
 	char requesting[MAX_URI_SIZE];
 	struct sockaddr_internet iface;
-	Socket::address via_address, from_address, request_address;
+	Socket::address via_address, request_address;
 	stack::session *session;
 	osip_header_t *header;
 	long header_expires;
@@ -532,7 +534,7 @@ private:
 	osip_uri_t *uri;
 	const char *via_host;
 	unsigned via_hops;
-	unsigned via_port;
+	unsigned via_port, from_port;
 	destination_t destination;
 
 	char *sip_realm;
