@@ -208,6 +208,7 @@ service::callback(1), mapped_array<MappedCall>(), TimerQueue()
 	anon = "anonymous";
 	restricted = trusted = published = proxy = NULL;
 	localnames = "localhost, localhost.localdomain";
+	domain = NULL;
 	ring_timer = 4000;
 	cfna_timer = 16000;
 	reset_timer = 6000;
@@ -704,6 +705,7 @@ void stack::reload(service *cfg)
 {
 	assert(cfg != NULL);	
 
+	const char *new_domain = "localdomain";
 	const char *new_proxy = NULL;
 	const char *key = NULL, *value;
 	linked_pointer<service::keynode> sp = cfg->getList("stack");
@@ -760,6 +762,8 @@ void stack::reload(service *cfg)
 				else
 					restricted = cfg->dup(value);
 			}
+			else if(!stricmp(key, "domain"))
+				new_domain = cfg->dup(value);
 			else if(!stricmp(key, "localnames"))
 				localhosts = cfg->dup(value);
 			else if(!stricmp(key, "trusted")) {
@@ -810,6 +814,7 @@ void stack::reload(service *cfg)
 
 	localnames = localhosts;
 	proxy = new_proxy;
+	domain = new_domain;
 
 	if(sip_family != AF_INET)
 		rtpproxy::enableIPV6();
